@@ -1,22 +1,8 @@
-/*****************************************************************************
- * This file is part of KDevelop
- * Copyright (c) 2011-2012 Sven Brauch <svenbrauch@googlemail.com>           *
- *                                                                           *
- * This program is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU General Public License as            *
- * published by the Free Software Foundation; either version 2 of            *
- * the License, or (at your option) any later version.                       *
- *                                                                           *           
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *   
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************
- */
+/*
+    SPDX-FileCopyrightText: 2011-2012 Sven Brauch <svenbrauch@googlemail.com>
 
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef PYCOMPLETIONHELPERS_H
 #define PYCOMPLETIONHELPERS_H
@@ -26,6 +12,7 @@
 #include <QString>
 #include <QList>
 #include <QVariant>
+#include <QRegularExpression>
 
 #include "pythoncompletionexport.h"
 
@@ -115,7 +102,7 @@ public:
     TokenListEntry weakPop() {
         m_internalPtr --;
         if ( m_internalPtr < 0 ) {
-            return TokenListEntry(ExpressionParser::InvalidStatus, QString::null, -1);
+            return TokenListEntry(ExpressionParser::InvalidStatus, QString(), -1);
         }
         return at(m_internalPtr);
     };
@@ -136,12 +123,12 @@ public:
     QString toString() {
         QString ret;
         int pos = 0;
-        foreach ( TokenListEntry item, *this ) {
+        for ( TokenListEntry item : *this ) {
             ret.append(
-                "offset " + QString::number(item.charOffset) + 
-                " position " + QString::number(pos) +
-                ": status " + QString::number(item.status) +
-                ", expression " + item.expression + "\n"
+                QStringLiteral("offset ") + QString::number(item.charOffset) +
+                QStringLiteral(" position ") + QString::number(pos) +
+                QStringLiteral(": status ") + QString::number(item.status) +
+                QStringLiteral(", expression ") + item.expression + QStringLiteral("\n")
             );
             pos ++;
         }
@@ -234,7 +221,7 @@ public:
 
     bool hasFillCharacter() const
     {
-        QStringList alignChars = QStringList() << "<" << ">" << "^" << "=";
+        QStringList alignChars = QStringList() << QStringLiteral("<") << QStringLiteral(">") << QStringLiteral("^") << QStringLiteral("=");
         return hasAlign() && alignChars.indexOf(m_formatSpec.at(1)) != -1;
     }
 
@@ -248,16 +235,16 @@ public:
 
     bool hasAlign() const
     {
-        QRegExp regex("^.?[<>\\^=]");
+        QRegularExpression regex(QStringLiteral("^.?[<>\\^=]"));
         return m_formatSpec.contains(regex);
     }
 
     bool hasPrecision() const
     {
-        if (fillCharacter() == '.') {
-            return m_formatSpec.count('.') == 2;
+        if (fillCharacter() == QLatin1Char('.')) {
+            return m_formatSpec.count(QLatin1Char('.')) == 2;
         }
-        return m_formatSpec.contains('.');
+        return m_formatSpec.contains(QLatin1Char('.'));
     }
 
     QChar type() const
@@ -267,23 +254,24 @@ public:
 
     bool hasType() const
     {
-        QStringList possibleTypes = QStringList() << "b" << "c" << "d" << "e" << "E"
-                                                  << "f" << "F" << "g" << "G" << "n"
-                                                  << "o" << "s" << "x" << "X" << "%";
+        QStringList possibleTypes = QStringList() << QStringLiteral("b") << QStringLiteral("c") << QStringLiteral("d") << QStringLiteral("e")
+                                                  << QStringLiteral("E") << QStringLiteral("f") << QStringLiteral("F") << QStringLiteral("g")
+                                                  << QStringLiteral("G") << QStringLiteral("n") << QStringLiteral("o") << QStringLiteral("s")
+                                                  << QStringLiteral("x") << QStringLiteral("X") << QStringLiteral("%");
 
         return (hasFormatSpec() && possibleTypes.indexOf(m_formatSpec.at(m_formatSpec.size() - 1)) != -1);
     }
 
     QString toString() const
     {
-        QString variable = "{" + m_identifier;
+        QString variable = QLatin1Char('{') + m_identifier;
         if (hasConversion()) {
-            variable += '!' + m_conversion;
+            variable += QLatin1Char('!') + m_conversion;
         }
         if (hasFormatSpec()) {
-            variable += ':' + m_formatSpec;
+            variable += QLatin1Char(':') + m_formatSpec;
         }
-        variable += "}";
+        variable += QLatin1Char('}');
 
         return variable;
     }
