@@ -16,7 +16,6 @@
 #include <tests/testcore.h>
 #include <tests/autotestshell.h>
 
-#include <ktexteditor_version.h>
 #include <KTextEditor/Editor>
 #include <KService>
 
@@ -35,7 +34,7 @@ QTEST_MAIN(Python::PyCompletionTest)
 Q_DECLARE_METATYPE(QList<Python::RangeInString>)
 
 static int testId = 0;
-static QString basepath = "/tmp/__kdevpythoncompletiontest.dir/";
+static QString basepath = QStringLiteral("/tmp/__kdevpythoncompletiontest.dir/");
 
 namespace Python {
 
@@ -47,7 +46,7 @@ QStandardItemModel& fakeModel() {
 }
 
 QString filenameForTestId(const int id) {
-    return basepath + "test_" + QString::number(id) + ".py";
+    return basepath + QStringLiteral("test_") + QString::number(id) + QStringLiteral(".py");
 }
 
 QString nextFilename() {
@@ -83,7 +82,7 @@ void PyCompletionTest::initShell()
     d.mkpath(basepath);
 
     auto doc_url = QDir::cleanPath(QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                                          "kdevpythonsupport/documentation_files/builtindocumentation.py"));
+                                                          QStringLiteral("kdevpythonsupport/documentation_files/builtindocumentation.py")));
 
     DUChain::self()->updateContextForUrl(IndexedString(doc_url), KDevelop::TopDUContext::AllDeclarationsContextsAndUses);
     ICore::self()->languageController()->backgroundParser()->parseDocuments();
@@ -93,56 +92,56 @@ void PyCompletionTest::initShell()
     KDevelop::CodeRepresentation::setDiskChangesForbidden(true);
 
     // now, create a nice little completion hierarchy
-    d.mkpath(basepath + "submoduledir");
-    d.mkpath(basepath + "submoduledir/anothersubdir");
-    makefile("toplevelmodule.py", "some_var = 3\ndef some_function(): pass\nclass some_class():\n def method(): pass");
-    makefile("submoduledir/__init__.py", "var_in_sub_init = 5");
-    makefile("submoduledir/subfile.py", "var_in_subfile = 5\nclass some_subfile_class():\n def method2(): pass");
-    makefile("submoduledir/anothersubdir/__init__.py", "var_in_subsub_init = 5");
-    makefile("submoduledir/anothersubdir/subsubfile.py", "var_in_subsubfile = 5\nclass another_subfile_class():"
-                                                      "\n def method3(): pass");
+    d.mkpath(basepath + QStringLiteral("submoduledir"));
+    d.mkpath(basepath + QStringLiteral("submoduledir/anothersubdir"));
+    makefile(QStringLiteral("toplevelmodule.py"), QStringLiteral("some_var = 3\ndef some_function(): pass\nclass some_class():\n def method(): pass"));
+    makefile(QStringLiteral("submoduledir/__init__.py"), QStringLiteral("var_in_sub_init = 5"));
+    makefile(QStringLiteral("submoduledir/subfile.py"), QStringLiteral("var_in_subfile = 5\nclass some_subfile_class():\n def method2(): pass"));
+    makefile(QStringLiteral("submoduledir/anothersubdir/__init__.py"), QStringLiteral("var_in_subsub_init = 5"));
+    makefile(QStringLiteral("submoduledir/anothersubdir/subsubfile.py"), QStringLiteral("var_in_subsubfile = 5\nclass another_subfile_class():"
+                                                      "\n def method3(): pass"));
 }
 
 void PyCompletionTest::testIdentifierMatching()
 {
-    QCOMPARE(camelCaseToUnderscore("FooBarBaz").toUtf8().data(), "foo_bar_baz");
-    QCOMPARE(camelCaseToUnderscore("fooBarbaz").toUtf8().data(),  "foo_barbaz");
+    QCOMPARE(camelCaseToUnderscore(QStringLiteral("FooBarBaz")).toUtf8().data(), "foo_bar_baz");
+    QCOMPARE(camelCaseToUnderscore(QStringLiteral("fooBarbaz")).toUtf8().data(),  "foo_barbaz");
 
-    QCOMPARE(identifierMatchQuality("foobar", "foobar"),  3);
-    QCOMPARE(identifierMatchQuality("foobar", "bar"),  2);
-    QCOMPARE(identifierMatchQuality("bar", "foobar"),  2);
-    QCOMPARE(identifierMatchQuality("foobarbaz", "bar"),  2);
-    QCOMPARE(identifierMatchQuality("bar", "foobarbaz"),  2);
-    QCOMPARE(identifierMatchQuality("FoobarBaz", "FoobarBang"), 1);
-    QCOMPARE(identifierMatchQuality("Foobar_Baz", "Foobar_Bang"), 1);
-    QCOMPARE(identifierMatchQuality("xydsf", "qkigfb"), 0);
-    QCOMPARE(identifierMatchQuality("ac_ac", "ac_ae"), 0);
-    QCOMPARE(identifierMatchQuality("AcAb", "AbDe"), 0);
+    QCOMPARE(identifierMatchQuality(QStringLiteral("foobar"), QStringLiteral("foobar")),  3);
+    QCOMPARE(identifierMatchQuality(QStringLiteral("foobar"), QStringLiteral("bar")),  2);
+    QCOMPARE(identifierMatchQuality(QStringLiteral("bar"), QStringLiteral("foobar")),  2);
+    QCOMPARE(identifierMatchQuality(QStringLiteral("foobarbaz"), QStringLiteral("bar")),  2);
+    QCOMPARE(identifierMatchQuality(QStringLiteral("bar"), QStringLiteral("foobarbaz")),  2);
+    QCOMPARE(identifierMatchQuality(QStringLiteral("FoobarBaz"), QStringLiteral("FoobarBang")), 1);
+    QCOMPARE(identifierMatchQuality(QStringLiteral("Foobar_Baz"), QStringLiteral("Foobar_Bang")), 1);
+    QCOMPARE(identifierMatchQuality(QStringLiteral("xydsf"), QStringLiteral("qkigfb")), 0);
+    QCOMPARE(identifierMatchQuality(QStringLiteral("ac_ac"), QStringLiteral("ac_ae")), 0);
+    QCOMPARE(identifierMatchQuality(QStringLiteral("AcAb"), QStringLiteral("AbDe")), 0);
 }
 
 void PyCompletionTest::testExpressionParserMisc()
 {
     // in completion, strings are filtered out and never contain " or ' chars.
-    ExpressionParser p("foobar(3, \"some_string\", func(), funcfunc(3, 5), \t");
+    ExpressionParser p(QStringLiteral("foobar(3, \"some_string\", func(), funcfunc(3, 5), \t"));
     bool ok;
     int expressionsSkipped = 0;
     p.skipUntilStatus(ExpressionParser::EventualCallFound, &ok, &expressionsSkipped);
     QVERIFY(ok);
     QCOMPARE(expressionsSkipped, 4); // number of params
-    QCOMPARE(p.getRemainingCode(), QString("foobar"));
+    QCOMPARE(p.getRemainingCode(), QString(QStringLiteral("foobar")));
     ExpressionParser::Status s;
     QString calledFunction = p.popExpression(&s);
     QVERIFY(s == ExpressionParser::ExpressionFound);
-    QCOMPARE(calledFunction, QString("foobar"));
+    QCOMPARE(calledFunction, QString(QStringLiteral("foobar")));
 
-    ExpressionParser q("hello(world, foo.bar[3].foobar(3, \"some_string\", func(), funcfunc(3, 5), \t");
+    ExpressionParser q(QStringLiteral("hello(world, foo.bar[3].foobar(3, \"some_string\", func(), funcfunc(3, 5), \t"));
     q.skipUntilStatus(ExpressionParser::EventualCallFound, &ok, &expressionsSkipped);
     QVERIFY(ok);
     QCOMPARE(expressionsSkipped, 4);
-    QCOMPARE(q.getRemainingCode(), QString("hello(world, foo.bar[3].foobar"));
+    QCOMPARE(q.getRemainingCode(), QString(QStringLiteral("hello(world, foo.bar[3].foobar")));
     calledFunction = q.popExpression(&s);
     QCOMPARE(s, ExpressionParser::ExpressionFound);
-    QCOMPARE(calledFunction, QString("foo.bar[3].foobar"));
+    QCOMPARE(calledFunction, QString(QStringLiteral("foo.bar[3].foobar")));
 }
 
 void PyCompletionTest::testExpressionParser()
@@ -197,14 +196,14 @@ const CompletionParameters PyCompletionTest::prepareCompletion(const QString& in
 
     Q_ASSERT(topContext);
 
-    Q_ASSERT(initCode.indexOf("%INVOKE") != -1);
+    Q_ASSERT(initCode.indexOf(QStringLiteral("%INVOKE")) != -1);
     QString copy = initCode;
-    QString allCode = copy.replace("%INVOKE", invokeCode);
+    QString allCode = copy.replace(QStringLiteral("%INVOKE"), invokeCode);
 
-    QStringList lines = allCode.split('\n');
+    QStringList lines = allCode.split(QLatin1Char('\n'));
     completion_data.cursorAt = CursorInRevision::invalid();
     for ( int i = 0; i < lines.length(); i++ ) {
-        int j = lines.at(i).indexOf("%CURSOR");
+        int j = lines.at(i).indexOf(QStringLiteral("%CURSOR"));
         if ( j != -1 ) {
             completion_data.cursorAt = CursorInRevision(i, j);
             break;
@@ -212,8 +211,8 @@ const CompletionParameters PyCompletionTest::prepareCompletion(const QString& in
     }
     Q_ASSERT(completion_data.cursorAt.isValid());
     // codeCompletionContext only gets passed the text until the place where completion is invoked
-    completion_data.snip = allCode.mid(0, allCode.indexOf("%CURSOR"));
-    completion_data.remaining = allCode.mid(allCode.indexOf("%CURSOR") + 7);
+    completion_data.snip = allCode.mid(0, allCode.indexOf(QStringLiteral("%CURSOR")));
+    completion_data.remaining = allCode.mid(allCode.indexOf(QStringLiteral("%CURSOR")) + 7);
 
     DUChainReadLocker lock;
     completion_data.contextAtCursor = DUContextPointer(topContext->findContextAt(completion_data.cursorAt, true));
@@ -227,7 +226,7 @@ const QList<CompletionTreeItem*> PyCompletionTest::runCompletion(const Completio
     PythonCodeCompletionContext* context = new PythonCodeCompletionContext(parameters.contextAtCursor, parameters.snip, parameters.remaining, parameters.cursorAt, 0, nullptr);
     bool abort = false;
     QList<CompletionTreeItem*> items;
-    foreach ( CompletionTreeItemPointer ptr, context->completionItems(abort, true) ) {
+    for ( CompletionTreeItemPointer ptr : context->completionItems(abort, true) ) {
         items << ptr.data();
         // those are leaked, but it's only a few kb while the tests are running. who cares.
         m_ptrs << ptr;
@@ -237,7 +236,7 @@ const QList<CompletionTreeItem*> PyCompletionTest::runCompletion(const Completio
 
 bool PyCompletionTest::containsItemForDeclarationNamed(const QList<CompletionTreeItem*> items, QString itemName)
 {
-    foreach ( const CompletionTreeItem* ptr, items ) {
+    for ( const CompletionTreeItem* ptr : items ) {
         if ( ptr->declaration() ) {
             if ( ptr->declaration()->identifier().toString() == itemName ) {
                 return true;
@@ -250,7 +249,7 @@ bool PyCompletionTest::containsItemForDeclarationNamed(const QList<CompletionTre
 bool PyCompletionTest::containsItemStartingWith(const QList<CompletionTreeItem*> items, const QString& itemName)
 {
     QModelIndex idx = fakeModel().index(0, KDevelop::CodeCompletionModel::Name);
-    foreach ( const CompletionTreeItem* ptr, items ) {
+    for ( const CompletionTreeItem* ptr : items ) {
         if ( ptr->data(idx, Qt::DisplayRole, nullptr).toString().startsWith(itemName) ) {
             return true;
         }
@@ -281,7 +280,7 @@ void PyCompletionTest::testImportCompletion()
     QFETCH(QString, completionCode);
     QFETCH(QString, expectedItem);
 
-    if ( expectedItem == "EMPTY" ) {
+    if ( expectedItem == QStringLiteral("EMPTY") ) {
         QVERIFY(completionListIsEmpty(invokeCode, completionCode));
     }
     else {
@@ -315,7 +314,7 @@ void PyCompletionTest::testCompletionAfterQuotes()
 {
     QFETCH(QString, invokeCode);
     QFETCH(QString, completionCode);
-    invokeCode = "testvar = 3\n" + invokeCode;
+    invokeCode = QStringLiteral("testvar = 3\n") + invokeCode;
     QVERIFY( ! completionListIsEmpty(invokeCode, completionCode) );
 }
 
@@ -336,9 +335,10 @@ void PyCompletionTest::testCompletionAfterQuotes_data()
 
 void PyCompletionTest::testNoImplicitMagicFunctions()
 {
-    QVERIFY(! itemInCompletionList("class my(): pass\nd = my()\n%INVOKE", "d.%CURSOR", "__get__") );
+    QVERIFY(! itemInCompletionList(QStringLiteral("class my(): pass\nd = my()\n%INVOKE"), QStringLiteral("d.%CURSOR"), QStringLiteral("__get__")) );
     QEXPECT_FAIL("", "Sorting needs to be fixed first before magic function completion can be re-enabled", Continue);
-    QVERIFY(itemInCompletionList("class my():\n def __get__(self): pass\nd = my()\n%INVOKE", "d.%CURSOR", "__get__") );
+    bool result = itemInCompletionList(QStringLiteral("class my():\n def __get__(self): pass\nd = my()\n%INVOKE"), QStringLiteral("d.%CURSOR"), QStringLiteral("__get__"));
+    QVERIFY(result);
 }
 
 void PyCompletionTest::testIntegralTypesImmediate()
@@ -390,9 +390,9 @@ void PyCompletionTest::testIntegralExpressionsDifferentContexts_data()
 
 void PyCompletionTest::testIgnoreCommentSignsInStringLiterals()
 {
-    QVERIFY( ! completionListIsEmpty("'#'%INVOKE", ".%CURSOR") );
-    QVERIFY( ! completionListIsEmpty("def addEntry(self,array):\n"
-                                     "  \"\"\"\"some comment\"\"\"\n  %INVOKE", "%CURSOR") );
+    QVERIFY( ! completionListIsEmpty(QStringLiteral("'#'%INVOKE"), QStringLiteral(".%CURSOR")) );
+    QVERIFY( ! completionListIsEmpty(QStringLiteral("def addEntry(self,array):\n"
+                                     "  \"\"\"\"some comment\"\"\"\n  %INVOKE"), QStringLiteral("%CURSOR")) );
 }
 
 void PyCompletionTest::testNoCompletionInCommentsOrStrings()
@@ -400,7 +400,7 @@ void PyCompletionTest::testNoCompletionInCommentsOrStrings()
     QFETCH(QString, invokeCode);
     QFETCH(QString, completionCode);
 
-    QVERIFY(! declarationInCompletionList(invokeCode, completionCode, "append"));
+    QVERIFY(! declarationInCompletionList(invokeCode, completionCode, QStringLiteral("append")));
 }
 
 void PyCompletionTest::testNoCompletionInCommentsOrStrings_data()
@@ -422,7 +422,7 @@ void PyCompletionTest::testImplementMethodCompletion()
 {
     QFETCH(QString, invokeCode);
     QFETCH(QString, completionCode);
-    QVERIFY(itemInCompletionList(invokeCode, completionCode, "__init__"));
+    QVERIFY(itemInCompletionList(invokeCode, completionCode, QStringLiteral("__init__")));
 }
 
 void PyCompletionTest::testImplementMethodCompletion_data()
@@ -441,22 +441,24 @@ void PyCompletionTest::testImplementMethodCompletion_data()
 
 void PyCompletionTest::testAutoBrackets()
 {
-    QList< CompletionTreeItem* > items = invokeCompletionOn("class Foo:\n @property\n def myprop(self): pass\n"
-                                                            "a=Foo()\n%INVOKE", "a.%CURSOR");
-    QVERIFY(containsItemForDeclarationNamed(items, "myprop"));
+    QList< CompletionTreeItem* > items = invokeCompletionOn(QStringLiteral("class Foo:\n @property\n def myprop(self): pass\n"
+                                                            "a=Foo()\n%INVOKE"), QStringLiteral("a.%CURSOR"));
+    QVERIFY(containsItemForDeclarationNamed(items, QStringLiteral("myprop")));
     CompletionTreeItem* item = nullptr;
-    foreach ( CompletionTreeItem* ptr, items ) {
+    for ( CompletionTreeItem* ptr : items ) {
         if ( ptr->declaration() ) {
-            if ( ptr->declaration()->identifier().toString() == "myprop" ) {
+            if ( ptr->declaration()->identifier().toString() == QStringLiteral("myprop") ) {
                 item = ptr;
                 break;
             }
         }
     }
     QVERIFY(item);
-    KService::Ptr documentService = KService::serviceByDesktopPath("katepart.desktop");
-    QVERIFY(documentService);
-    KTextEditor::Document* document = documentService->createInstance<KTextEditor::Document>(this);
+    // get access to the global editor singleton
+    auto editor = KTextEditor::Editor::instance();
+    auto document = editor->createDocument(this);
+
+    // create a widget to display the document
     auto view = document->createView(nullptr);
     QVERIFY(document);
     item->execute(view, KTextEditor::Range(0, 0, 0, 0));
@@ -465,32 +467,32 @@ void PyCompletionTest::testAutoBrackets()
 
 void PyCompletionTest::testExceptionCompletion()
 {
-    QList< CompletionTreeItem* > items = invokeCompletionOn("localvar = 3\nraise %INVOKE", "%CURSOR");
-    QVERIFY(containsItemForDeclarationNamed(items, "Exception"));
-    QVERIFY(! containsItemForDeclarationNamed(items, "localvar"));
+    QList< CompletionTreeItem* > items = invokeCompletionOn(QStringLiteral("localvar = 3\nraise %INVOKE"), QStringLiteral("%CURSOR"));
+    QVERIFY(containsItemForDeclarationNamed(items, QStringLiteral("Exception")));
+    QVERIFY(! containsItemForDeclarationNamed(items, QStringLiteral("localvar")));
 
-    items = invokeCompletionOn("localvar = 3\n%INVOKE", "try: pass\nexcept %CURSOR");
-    QVERIFY(containsItemForDeclarationNamed(items, "Exception"));
-    QVERIFY(! containsItemForDeclarationNamed(items, "localvar"));
+    items = invokeCompletionOn(QStringLiteral("localvar = 3\n%INVOKE"), QStringLiteral("try: pass\nexcept %CURSOR"));
+    QVERIFY(containsItemForDeclarationNamed(items, QStringLiteral("Exception")));
+    QVERIFY(! containsItemForDeclarationNamed(items, QStringLiteral("localvar")));
 }
 
 void PyCompletionTest::testGeneratorCompletion()
 {
-    QVERIFY(itemInCompletionList("%INVOKE", "foobar = [item for %CURSOR", "item in"));
-    QVERIFY(itemInCompletionList("%INVOKE", "foobar = [key, value for %CURSOR", "key, value in"));
-    QVERIFY(itemInCompletionList("%INVOKE", "foobar = [str(key + value) for %CURSOR", "key, value in"));
-    QVERIFY(itemInCompletionList("%INVOKE\ndec_l8r=3", "foobar = [dec_l8r for %CURSOR", "dec_l8r in"));
+    QVERIFY(itemInCompletionList(QStringLiteral("%INVOKE"), QStringLiteral("foobar = [item for %CURSOR"), QStringLiteral("item in")));
+    QVERIFY(itemInCompletionList(QStringLiteral("%INVOKE"), QStringLiteral("foobar = [key, value for %CURSOR"), QStringLiteral("key, value in")));
+    QVERIFY(itemInCompletionList(QStringLiteral("%INVOKE"), QStringLiteral("foobar = [str(key + value) for %CURSOR"), QStringLiteral("key, value in")));
+    QVERIFY(itemInCompletionList(QStringLiteral("%INVOKE\ndec_l8r=3"), QStringLiteral("foobar = [dec_l8r for %CURSOR"), QStringLiteral("dec_l8r in")));
 }
 
 void PyCompletionTest::testInheritanceCompletion()
 {
-    QList< CompletionTreeItem* > items = invokeCompletionOn("class parentClass: pass\n%INVOKE", "class childClass(%CURSOR");
-    QVERIFY(containsItemForDeclarationNamed(items, "parentClass"));
-    items = invokeCompletionOn("class parentClass: pass\nclass childClass(%INVOKE): pass", "%CURSOR");
-    QVERIFY(containsItemForDeclarationNamed(items, "parentClass"));
-    items = invokeCompletionOn("class parentClass:\n class blubb: pass\nclass childClass(%INVOKE): pass", "parentClass.%CURSOR");
-    QVERIFY(! containsItemForDeclarationNamed(items, "parentClass"));
-    QVERIFY(containsItemForDeclarationNamed(items, "blubb"));
+    QList< CompletionTreeItem* > items = invokeCompletionOn(QStringLiteral("class parentClass: pass\n%INVOKE"), QStringLiteral("class childClass(%CURSOR"));
+    QVERIFY(containsItemForDeclarationNamed(items, QStringLiteral("parentClass")));
+    items = invokeCompletionOn(QStringLiteral("class parentClass: pass\nclass childClass(%INVOKE): pass"), QStringLiteral("%CURSOR"));
+    QVERIFY(containsItemForDeclarationNamed(items, QStringLiteral("parentClass")));
+    items = invokeCompletionOn(QStringLiteral("class parentClass:\n class blubb: pass\nclass childClass(%INVOKE): pass"), QStringLiteral("parentClass.%CURSOR"));
+    QVERIFY(! containsItemForDeclarationNamed(items, QStringLiteral("parentClass")));
+    QVERIFY(containsItemForDeclarationNamed(items, QStringLiteral("blubb")));
 }
 
 void PyCompletionTest::testAddImportCompletion()
@@ -520,23 +522,20 @@ void PyCompletionTest::testFunctionDeclarationCompletion()
     QFETCH(QString, expectedReplacement);
 
     QString documentCode = completionCode;
-    documentCode.replace("%INVOKE", invokeCode).replace("%CURSOR", "");
+    documentCode.replace(QStringLiteral("%INVOKE"), invokeCode).replace(QStringLiteral("%CURSOR"), QString());
 
     QString expectedCode = completionCode;
-    expectedCode.replace("%INVOKE", expectedReplacement);
+    expectedCode.replace(QStringLiteral("%INVOKE"), expectedReplacement);
 
     const QList<CompletionTreeItem *> completionItems = invokeCompletionOn(completionCode, invokeCode);
 
     QVERIFY( ! completionItems.isEmpty() );
 
-    KService::Ptr documentService = KService::serviceByDesktopPath("katepart.desktop");
-    QVERIFY(documentService);
-    KTextEditor::Document* document = documentService->createInstance<KTextEditor::Document>(this);
-    QVERIFY(document);
+    auto editor = KTextEditor::Editor::instance();
+    auto document = editor->createDocument(this);
     document->setText(documentCode);
 
     auto view = document->createView(nullptr);
-
     completionItems.first()->execute(view, executeRange);
     QCOMPARE(document->text(), expectedCode);
 }
@@ -629,7 +628,7 @@ void PyCompletionTest::testStringFormatter()
 
     for (int i = 0; i < string.size(); i++) {
         bool expectedInsideVariable = false;
-        foreach (RangeInString range, expectedVariablePositions) {
+        for (RangeInString range : expectedVariablePositions) {
             if (i >= range.beginIndex && i <= range.endIndex) {
                 expectedInsideVariable = true;
                 break;
@@ -663,7 +662,7 @@ QString repeat_distinct(const QString& code, int count) {
     QString line;
     for ( int i = 0; i < count; i++ ) {
         line = code;
-        result.append(line.replace(QString("%X"), QString::number(i)));
+        result.append(line.replace(QStringLiteral("%X"), QString::number(i)));
     }
     return result;
 }
@@ -690,10 +689,10 @@ void PyCompletionTest::completionBenchTest_data()
     QTest::newRow("deep_function") << "foo(bar(baz(bang([]%INVOKE))))" << ".%CURSOR";
     QTest::newRow("class_completion") << "class my(): pass\nd = my()\n%INVOKE" << "d.%CURSOR";
 
-    QString many_globals = repeat_distinct("a%X=%X\n", 1000);
+    QString many_globals = repeat_distinct(QStringLiteral("a%X=%X\n"), 1000);
 
-    QTest::newRow("function_many_globals") << many_globals + "%INVOKE" << "foo(%CURSOR";
-    QTest::newRow("variable_completion_many_globals") << many_globals + "%INVOKE" << "b = a%CURSOR";
+    QTest::newRow("function_many_globals") << many_globals + QStringLiteral("%INVOKE") << "foo(%CURSOR";
+    QTest::newRow("variable_completion_many_globals") << many_globals + QStringLiteral("%INVOKE") << "b = a%CURSOR";
 }
 
 }
